#[derive(Default, Clone)]
pub struct Configuration {}

impl crate::IConfiguration for Configuration {}

impl Copy for Configuration {}

impl Configuration {
    fn new() -> Self {
        Self::default()
    }
}

pub fn init() -> Configuration {
    Configuration::new()
}
